compose

Function compose 

pub fn compose(
    store: &Store,
    home: &Path,
    tools: &[EnvTool],
) -> VtaResult<PathBuf>
Compose (or refresh) the environment view for tools, returning its bin directory. Executables are linked from the store with the cheapest available strategy (docs/09-store.md).